@@ -100,6 +100,6 @@ def verify_user_token(token,allowed_permissions=None):
     Auth.set_user(user)
         # will check from the AUTH if the user has the requested allowed_permissions above 
         # if the user has the permission then will return true else will return false
-    if not response.get("is_valid_permission"):
-        raise AppMissingAuthError("You have not enough permission in your role")
+    # if not response.get("is_valid_permission"):
+    #     raise AppMissingAuthError("You have not enough permission in your role")
     return user
